==> lambdasns-1.124.0-sources.jar: software/amazon/awsconstructs/services/lambdasns/LambdaToSns.java <==
package software.amazon.awsconstructs.services.lambdasns;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.35.0 (build 6ebef96)", date = "2021-09-29T21:29:49.281Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdasns.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-sns.LambdaToSns")
public class LambdaToSns extends software.amazon.awscdk.core.Construct {

    protected LambdaToSns(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToSns(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToSns(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return software.amazon.jsii.Kernel.get(this, "snsTopic", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.Topic.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdasns.LambdaToSns> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingTopicObj Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. This parameter is required.
         */
        public Builder existingTopicObj(final software.amazon.awscdk.services.sns.Topic existingTopicObj) {
            this.props.existingTopicObj(existingTopicObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the SNS topic arn environment variable set for the Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param topicArnEnvironmentVariableName Optional Name for the SNS topic arn environment variable set for the Lambda function. This parameter is required.
         */
        public Builder topicArnEnvironmentVariableName(final java.lang.String topicArnEnvironmentVariableName) {
            this.props.topicArnEnvironmentVariableName(topicArnEnvironmentVariableName);
            return this;
        }

        /**
         * Optional Name for the SNS topic name environment variable set for the Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param topicNameEnvironmentVariableName Optional Name for the SNS topic name environment variable set for the Lambda function. This parameter is required.
         */
        public Builder topicNameEnvironmentVariableName(final java.lang.String topicNameEnvironmentVariableName) {
            this.props.topicNameEnvironmentVariableName(topicNameEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final software.amazon.awscdk.services.sns.TopicProps topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdasns.LambdaToSns build() {
            return new software.amazon.awsconstructs.services.lambdasns.LambdaToSns(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdasns-1.167.0-sources.jar: software/amazon/awsconstructs/services/lambdasns/LambdaToSns.java <==
package software.amazon.awsconstructs.services.lambdasns;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.64.0 (build 4c1eae8)", date = "2022-08-17T16:43:42.958Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdasns.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-sns.LambdaToSns")
public class LambdaToSns extends software.amazon.awscdk.core.Construct {

    protected LambdaToSns(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToSns(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToSns(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sns.Topic getSnsTopic() {
        return software.amazon.jsii.Kernel.get(this, "snsTopic", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sns.Topic.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdasns.LambdaToSns> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdasns.LambdaToSnsProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingTopicObj Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. This parameter is required.
         */
        public Builder existingTopicObj(final software.amazon.awscdk.services.sns.Topic existingTopicObj) {
            this.props.existingTopicObj(existingTopicObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the arn of the Topic.
         * <p>
         * Default: - SNS_TOPIC_ARN
         * <p>
         * @return {@code this}
         * @param topicArnEnvironmentVariableName Optional Name for the Lambda function environment variable set to the arn of the Topic. This parameter is required.
         */
        public Builder topicArnEnvironmentVariableName(final java.lang.String topicArnEnvironmentVariableName) {
            this.props.topicArnEnvironmentVariableName(topicArnEnvironmentVariableName);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the Topic.
         * <p>
         * Default: - SNS_TOPIC_NAME
         * <p>
         * @return {@code this}
         * @param topicNameEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the Topic. This parameter is required.
         */
        public Builder topicNameEnvironmentVariableName(final java.lang.String topicNameEnvironmentVariableName) {
            this.props.topicNameEnvironmentVariableName(topicNameEnvironmentVariableName);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the SNS topic.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param topicProps Optional user provided properties to override the default properties for the SNS topic. This parameter is required.
         */
        public Builder topicProps(final software.amazon.awscdk.services.sns.TopicProps topicProps) {
            this.props.topicProps(topicProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdasns.LambdaToSns}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdasns.LambdaToSns build() {
            return new software.amazon.awsconstructs.services.lambdasns.LambdaToSns(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
